"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const commander_1 = require("commander");
const constants_1 = require("./constants");
const fetch_1 = require("./fetch");
const format_1 = require("./format");
const program = new commander_1.Command()
    .version(constants_1.default.version)
    .description(constants_1.default.description)
    .arguments('<url> [headers ...]')
    .option('-o, --output-file <path>', 'output file for generated type definitions, by default redirects to stdout')
    .option('-a, --no-field-arguments', 'remove the special property `$__arguments`')
    .option('-t, --no-field-types', 'remove the special properties `$__objects` and `$__scalars`')
    .on('--help', () => console.log('\n  Example:\n\n    graphql-url-to-typescript -o ./github.d.ts https://api.github.com/graphql \'Authorization:Bearer <your GitHub personal access token>\'\n\n  Notes:\n\n    `$__arguments` contains the type definitions of field arguments\n    `$__scalars`   gathers the scalar properties of an interface\n    `$__objects`   gathers the object properties of an interface'))
    .parse(process.argv);
const output = program.outputFile ? fs
    .createWriteStream(path.resolve(process.cwd(), program.outputFile))
    .on('error', error => {
    console.error(error.message);
    process.exit(1);
}) : null;
const [url, ...headers] = program.args;
fetch_1.default(url, { headers })
    .then(format_1.default({
    includeArguments: program.fieldArguments,
    includeScalars: program.fieldTypes,
    includeObjects: program.fieldTypes
}))
    .then(typeDefinitions => {
    if (!output)
        return console.log(typeDefinitions);
    output.write(typeDefinitions);
    output.close();
})
    .catch(error => {
    console.error(error instanceof Error ? error.message : error);
    process.exit(1);
});
